aboutsummaryrefslogtreecommitdiffstats
path: root/lib/private
diff options
context:
space:
mode:
authorCôme Chilliet <come.chilliet@nextcloud.com>2024-09-09 10:45:41 +0200
committerCôme Chilliet <91878298+come-nc@users.noreply.github.com>2024-09-09 10:46:29 +0200
commit90a948506bad93c4ebdbf4dfdbdd97a91a847c12 (patch)
tree241a83ab31c24838e9f36b9705c5e3b954ac57d7 /lib/private
parent42c5a60c2944d9f509095bca0849fdb7803ae5b9 (diff)
downloadnextcloud-server-90a948506bad93c4ebdbf4dfdbdd97a91a847c12.tar.gz
nextcloud-server-90a948506bad93c4ebdbf4dfdbdd97a91a847c12.zip
chore: Make parameter name more explicit
Signed-off-by: Côme Chilliet <come.chilliet@nextcloud.com>
Diffstat (limited to 'lib/private')
-rw-r--r--lib/private/OCS/ApiHelper.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/private/OCS/ApiHelper.php b/lib/private/OCS/ApiHelper.php
index 4679b4da864..f69b540eafa 100644
--- a/lib/private/OCS/ApiHelper.php
+++ b/lib/private/OCS/ApiHelper.php
@@ -21,9 +21,9 @@ class ApiHelper {
/**
* Respond to a call
* @psalm-taint-escape html
* @param int $httpStatusCode force the HTTP status code, only used for the special case of maintenance mode which return 503 even for v1
*/
- public static function respond(int $statusCode, string $statusMessage, array $headers = [], ?int $httpStatusCode = null): void {
+ public static function respond(int $statusCode, string $statusMessage, array $headers = [], ?int $overrideHttpStatusCode = null): void {
$request = Server::get(IRequest::class);
$format = $request->getParam('format', 'xml');
if (self::isV2($request)) {
@@ -47,7 +47,7 @@ class ApiHelper {
header($name . ': ' . $value);
}
- http_response_code($httpStatusCode ?? $response->getStatus());
+ http_response_code($overrideHttpStatusCode ?? $response->getStatus());
self::setContentType($format);
$body = $response->render();
@@ -21,9 +21,9 @@ class ApiHelper {
* Respond to a call
* @psalm-taint-escape html
- * @param int $httpStatusCode force the HTTP status code, only used for the special case of maintenance mode which return 503 even for v1
+ * @param int $overrideHttpStatusCode force the HTTP status code, only used for the special case of maintenance mode which return 503 even for v1
*/